==> piwigo-2.10.2.zip: piwigo/themes/modus/language/cs_CZ/theme.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['%d album'] = '%d album';
$lang['%d albums'] = '%d alba';
$lang['Explore'] = 'Prozkoumat';
$lang['modus_theme'] = 'modus_theme';
$lang['%d pixels'] = '%d pixelů';
$lang['Album thumbnails'] = 'Náhledy alba';
$lang['Default size for thumbnails'] = 'Výchozí rozlišení pro náhledy';
$lang['Default size for thumbnails on high density display (retina)'] = 'Výchozí velikosti náhledů pro vysoká rozlišení (retina)';
$lang['Default sizes'] = 'Výchozí velikosti';
$lang['Display page banner'] = 'Zobraz banner stránky';
$lang['Modus theme config'] = 'nastavení Modus šablony';
$lang['Skin'] = 'Vzhled';
$lang['Use square thumbs'] = 'Používat čtvercové náhledy';

==> piwigo-15.7.0.zip: piwigo/themes/modus/language/cs_CZ/theme.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['%d album'] = '%d album';
$lang['%d albums'] = '%d alb';
$lang['Explore'] = 'Prozkoumat';
$lang['modus_theme'] = 'modus_theme';
$lang['%d pixels'] = '%d pixelů';
$lang['Album thumbnails'] = 'Náhledy alba';
$lang['Default size for thumbnails'] = 'Výchozí velikost náhledů';
$lang['Default size for thumbnails on high density display (retina)'] = 'Výchozí velikosti náhledů pro obrazovky s vysokým rozlišením (retina)';
$lang['Default sizes'] = 'Výchozí velikosti';
$lang['Display page banner'] = 'Zobraz banner stránky';
$lang['Modus theme config'] = 'nastavení Modus šablony';
$lang['Skin'] = 'Vzhled';
$lang['Use square thumbs'] = 'Používat čtvercové náhledy';
$lang['Admin'] = 'Admin';
